import QtQml 2.12
import QtQuick 2.12
import QtQuick.Controls 2.4
import QtQuick.Controls.Material 2.4
import QtQuick.Window 2.12
import QtQuick.Layouts 1.12

import MultiTouch 1.0

Rectangle {
    id: root

    property bool enablePinch: true
    property alias minimumScale: pinchHandler.minimumScale
    property alias maximumScale: pinchHandler.maximumScale
    property alias minimumRotation: pinchHandler.minimumRotation
    property alias maximumRotation: pinchHandler.maximumRotation
    property alias minimumX: pinchHandler.minimumX
    property alias minimumY: pinchHandler.minimumY
    property alias maximumX: pinchHandler.maximumX
    property alias maximumY: pinchHandler.maximumY
    property alias minimumPointCount: pinchHandler.minimumPointCount

    function transformationDetails() {
        return qsTr("fingers to pinch or drag: %1\n").arg(pinchHandler.minimumPointCount)
                + qsTr("activePinch: %1\n").arg(pinchHandler.active)
                + qsTr("activeDrag: %1\n").arg(dragHandler.active)
                + qsTr("minimumScale: %1\n").arg(pinchHandler.minimumScale)
                + qsTr("scale: %1\n").arg(pinchHandler.scale)
                + qsTr("maximumScale: %1\n").arg(pinchHandler.maximumScale)
                + qsTr("activeScale: %1\n").arg(pinchHandler.activeScale)
                + qsTr("minimumRotation: %1\n").arg(pinchHandler.minimumRotation)
                + qsTr("rotation: %1\n").arg(pinchHandler.rotation)
                + qsTr("maximumRotation: %1\n").arg(pinchHandler.maximumRotation)
                + qsTr("minimumX: %1\n").arg(pinchHandler.minimumX)
                + qsTr("minimumY: %1\n").arg(pinchHandler.minimumY)
                + qsTr("translation: %1\n").arg(pinchHandler.translation)
                + qsTr("maximumX: %1\n").arg(pinchHandler.maximumX)
                + qsTr("maximumY: %1\n").arg(pinchHandler.maximumY)
    }

    implicitWidth: 400
    implicitHeight: 400
    border {
        width: 1
        color: "black"
    }
    antialiasing: true
    
    Text {
        x: 5
        y: 5
        text: root.transformationDetails()
    }
    
    PinchHandler {
        id: pinchHandler

        enabled: root.enablePinch
    }
    DragHandler {
        id: dragHandler

        minimumPointCount: root.minimumPointCount
        maximumPointCount: minimumPointCount
        enabled: !root.enablePinch
    }

    states: [
        State {
            when: pinchHandler.active
            PropertyChanges {
                target: root
                border.width: 2
                border.color: "red"
            }
        },
        State {
            when: dragHandler.active
            PropertyChanges {
                target: root
                border.width: 2
                border.color: "blue"
            }
        }
    ]
}
